==> tuia-advert-center-api-1.5.9-20180816.080808-66-sources.jar: cn/com/duiba/tuia/core/api/remoteservice/RemoteFinanceBackendService.java <==
/**
 * 文件名： AccountFinanceService.java 此类描述的是： 作者: sunjiangrong 创建时间: 2016年4月14日 下午1:56:31
 */
package cn.com.duiba.tuia.core.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.core.api.dto.AccountFinanceDto;
import cn.com.duiba.tuia.core.api.dto.FinanceRecordDto;
import cn.com.duiba.tuia.core.api.dto.PageDto;
import cn.com.duiba.tuia.core.api.dto.finance.AccountBalanceRecordDto;
import cn.com.duiba.tuia.core.api.dto.req.ReqGetAdvertStatisticsDto;
import cn.com.duiba.tuia.core.api.dto.req.ReqPageQueryAccount;
import cn.com.duiba.tuia.core.api.dto.req.ReqPageQueryFinanceRecord;
import cn.com.duiba.tuia.core.api.dto.req.account.AccountFinanceStatisticsQueryDto;
import cn.com.duiba.tuia.core.api.dto.rsp.FinanceInfoDto;
import cn.com.duiba.tuia.core.api.dto.rsp.PspAdvertStatisticsDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.AdvertiserDataSnapshotCountDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.DataSnapshotCountDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 账号财务记录相关业务 <功能详细描述>.
 *
 * @author: sunjiangrong
 * @创建时间: 2016年4月14日 下午1:56:31
 * @version:
 */
@AdvancedFeignClient
public interface RemoteFinanceBackendService {

    /**
     * 创建资金账户.
     *
     * @param t the t
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> insertAccountFinance(AccountFinanceDto t);

    /**
     * 获取某账号的当日财务信息.
     *
     * @param accountId the account id
     * @param userType  the user type
     * @return the finance
     */
    DubboResult<Map<String, Object>> getFinance(Long accountId, int userType);

    Map<String, Object> getFinanceByMainType(Long accountId, int userType, Integer effectiveMainType);

    Map<String, Object> getAgentFinanceByMainType(Long agentId, Integer effectiveMainType);

    /**
     * 获取代理商的当日财务信息.
     *
     * @param agentId the agent id
     * @return the finance by agent
     */
    DubboResult<Map<String, Object>> getFinanceByAgent(Long agentId);

    /**
     * 修改某账号的账户预算.
     *
     * @param accountId    the account id
     * @param budgetPerDay the budget per day
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> updateAccountBudgetPerDay(Long accountId, Long budgetPerDay);

    /**
     * 代理商根据广告主邮箱地址获取广告主信息.
     *
     * @param agentId      代理商ID
     * @param advertiserId the advertiser id
     * @return 广告主账户信息
     */
    DubboResult<Map<String, Object>> getFinanceInfoByAdvertiserId(Long agentId, long advertiserId);

    Map<String, Object> getAdvertiserFinanceInfoByMainType(Long agentId, long advertiserId, Integer effectiveMainType);

    /**
     * 代理商获取广告主资金账号列表.
     *
     * @param req the req
     * @return the finance info list
     */
    DubboResult<PageDto<FinanceInfoDto>> getFinanceInfoList(ReqPageQueryAccount req);

    /**
     * 获取自身流水记录.
     *
     * @param req the req
     * @return the finance record list
     */
    DubboResult<PageDto<FinanceRecordDto>> getFinanceRecordList(ReqPageQueryFinanceRecord req);

    /**
     * 代理商获取广告主流水记录.
     *
     * @param agentId the agent id
     * @param req     the req
     * @return the finance record list by agent
     */
    DubboResult<PageDto<FinanceRecordDto>> getFinanceRecordListByAgent(Long agentId, ReqPageQueryFinanceRecord req);

    /**
     * 代理商给广告主充值.
     *
     * @param agentId      the agent id
     * @param advertiserId the advertiser id
     * @param amount       the amount
     * @return the dubbo result< map< string, object>>
     */
    DubboResult<Map<String, Object>> charge(Long agentId, Long advertiserId, Long amount);

    /**
     * 代理商从广告主回拨金额
     *
     * @author chencheng
     * @param agentId
     * @param advertiserId
     * @param amount
     * @return
     */
    DubboResult<Map<String, Object>> callBackToAgent(Long agentId, Long advertiserId, Long amount);
    
    /**
     * 获取某账号的广告统计.
     *
     * @param req the req
     * @return the advert statistics
     */
    DubboResult<PspAdvertStatisticsDto> getAdvertStatistics(ReqGetAdvertStatisticsDto req);

    List<AccountFinanceDto> listByAccountIds(List<Long> accountIds);

    /**
     * 计数余额记录
     */
    Integer countBalanceRecord(AccountFinanceStatisticsQueryDto req);

    /**
     * 查询余额记录列表
     *
     * @param req
     * @return 余额记录列表
     */
    List<AccountBalanceRecordDto> selectBalanceRecordList(AccountFinanceStatisticsQueryDto req);

    /**
     * 获取代理商的数据总览
     * @param accountIds
     * @param beginTime
     * @param endTime
     * @param agentAccountId
     * @return
     */
    DataSnapshotCountDto getAgentDataSnapshot(List<Long> accountIds, Date beginTime,Date endTime,Long agentAccountId, Integer effectiveMainType);

    /**
     * 获取广告主的数据总览
     * @param accountId
     * @param beginTime
     * @param endTime
     * @return
     */
    AdvertiserDataSnapshotCountDto getAdvertiserDataSnapshot(Long accountId, Date beginTime, Date endTime, Integer effectiveMainType);
}

==> tuia-advert-center-api-2.4.51-sources.jar: cn/com/duiba/tuia/core/api/remoteservice/RemoteFinanceBackendService.java <==
/**
 * 文件名： AccountFinanceService.java 此类描述的是： 作者: sunjiangrong 创建时间: 2016年4月14日 下午1:56:31
 */
package cn.com.duiba.tuia.core.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.core.api.dto.AccountDto;
import cn.com.duiba.tuia.core.api.dto.AccountFinanceDto;
import cn.com.duiba.tuia.core.api.dto.FinanceRecordDto;
import cn.com.duiba.tuia.core.api.dto.PageDto;
import cn.com.duiba.tuia.core.api.dto.finance.AccountBalanceRecordDto;
import cn.com.duiba.tuia.core.api.dto.finance.AccountNewMainTypeFinanceDTO;
import cn.com.duiba.tuia.core.api.dto.req.ReqGetAdvertStatisticsDto;
import cn.com.duiba.tuia.core.api.dto.req.ReqPageQueryAccount;
import cn.com.duiba.tuia.core.api.dto.req.ReqPageQueryFinanceRecord;
import cn.com.duiba.tuia.core.api.dto.req.account.AccountFinanceStatisticsQueryDto;
import cn.com.duiba.tuia.core.api.dto.rsp.FinanceInfoDto;
import cn.com.duiba.tuia.core.api.dto.rsp.PspAdvertStatisticsDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.AdvertiserDataSnapshotCountDto;
import cn.com.duiba.tuia.core.api.dto.rsp.account.DataSnapshotCountDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 账号财务记录相关业务 <功能详细描述>.
 *
 * @author: sunjiangrong
 * @创建时间: 2016年4月14日 下午1:56:31
 * @version:
 */
@AdvancedFeignClient
public interface RemoteFinanceBackendService {

    /**
     * 创建资金账户.
     *
     * @param t the t
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> insertAccountFinance(AccountFinanceDto t);

    /**
     * 获取某账号的当日财务信息.
     *
     * @param accountId the account id
     * @param userType  the user type
     * @return the finance
     */
    DubboResult<Map<String, Object>> getFinance(Long accountId, int userType);

    Map<String, Object> getFinanceByMainType(Long accountId, int userType, Integer effectiveMainType);

    Map<String, Object> getAgentFinanceByMainType(Long agentId, Integer effectiveMainType);

    /**
     * 获取代理商的当日财务信息.
     *
     * @param agentId the agent id
     * @return the finance by agent
     */
    DubboResult<Map<String, Object>> getFinanceByAgent(Long agentId);

    /**
     * 修改某账号的账户预算.
     *
     * @param accountId    the account id
     * @param budgetPerDay the budget per day
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> updateAccountBudgetPerDay(Long accountId, Long budgetPerDay);

    /**
     * 代理商根据广告主邮箱地址获取广告主信息.
     *
     * @param agentId      代理商ID
     * @param advertiserId the advertiser id
     * @return 广告主账户信息
     */
    DubboResult<Map<String, Object>> getFinanceInfoByAdvertiserId(Long agentId, long advertiserId);

    Map<String, Object> getAdvertiserFinanceInfoByMainType(Long agentId, long advertiserId, Integer effectiveMainType);

    /**
     * 代理商获取广告主资金账号列表.
     *
     * @param req the req
     * @return the finance info list
     */
    DubboResult<PageDto<FinanceInfoDto>> getFinanceInfoList(ReqPageQueryAccount req);

    /**
     * 获取自身流水记录.
     *
     * @param req the req
     * @return the finance record list
     */
    DubboResult<PageDto<FinanceRecordDto>> getFinanceRecordList(ReqPageQueryFinanceRecord req);

    /**
     * 代理商获取广告主流水记录.
     *
     * @param agentId the agent id
     * @param req     the req
     * @return the finance record list by agent
     */
    DubboResult<PageDto<FinanceRecordDto>> getFinanceRecordListByAgent(Long agentId, ReqPageQueryFinanceRecord req);

    /**
     * 代理商给广告主充值.
     *
     * @param agentId      the agent id
     * @param advertiserId the advertiser id
     * @param amount       the amount
     * @return the dubbo result< map< string, object>>
     */
    DubboResult<Map<String, Object>> charge(Long agentId, Long advertiserId, Long amount);

    /**
     * 代理商从广告主回拨金额
     *
     * @author chencheng
     * @param agentId
     * @param advertiserId
     * @param amount
     * @return
     */
    DubboResult<Map<String, Object>> callBackToAgent(Long agentId, Long advertiserId, Long amount);
    
    /**
     * 获取某账号的广告统计.
     *
     * @param req the req
     * @return the advert statistics
     */
    DubboResult<PspAdvertStatisticsDto> getAdvertStatistics(ReqGetAdvertStatisticsDto req);

    List<AccountFinanceDto> listByAccountIds(List<Long> accountIds);

    /**
     * 计数余额记录
     */
    Integer countBalanceRecord(AccountFinanceStatisticsQueryDto req);

    /**
     * 查询余额记录列表
     *
     * @param req
     * @return 余额记录列表
     */
    List<AccountBalanceRecordDto> selectBalanceRecordList(AccountFinanceStatisticsQueryDto req);

    /**
     * 获取代理商的数据总览
     * @param accountIds
     * @param beginTime
     * @param endTime
     * @param agentAccountId
     * @return
     */
    DataSnapshotCountDto getAgentDataSnapshot(List<Long> accountIds, Date beginTime,Date endTime,Long agentAccountId, Integer effectiveMainType);

    /**
     * 获取广告主的数据总览
     * @param accountId
     * @param beginTime
     * @param endTime
     * @return
     */
    AdvertiserDataSnapshotCountDto getAdvertiserDataSnapshot(Long accountId, Date beginTime, Date endTime, Integer effectiveMainType);

    /**
     * 获取账户余额
     * @param accountId  账户id
     * @param effectMainType 账户类型
     * @return
     */
    AccountNewMainTypeFinanceDTO getAccountFinanceByMainType(Long accountId, Integer effectMainType);
}
